@@ -23,12 +23,16 @@
 #                        520 Edgemont Road
 #                        Charlottesville, VA 22903-2475 USA
 #
-# $Id$
 
-from table import table,taql
-from tableutil import makescacoldesc,makearrcoldesc,makecoldesc,maketabdesc
 import numpy as np
 
+from casacore.tables.table import table, taql
+from casacore.tables.tableutil import makescacoldesc, makearrcoldesc,\
+    makecoldesc, maketabdesc
+from casacore import six
+
+
+
 def addImagingColumns(msname, ack=True):
     """ Add the columns to an MS needed for the casa imager.
 
@@ -62,23 +66,23 @@ def addImagingColumns(msname, ack=True):
         dminfo = {'TYPE': 'TiledShapeStMan', 'SPEC': {'DEFAULTTILESHAPE':[4,32,128]}}
     # Add the columns (if not existing). Use the description of the DATA column.
     if 'MODEL_DATA' in cnames:
-        print 'Column MODEL_DATA not added; it already exists'
+        six.print_("Column MODEL_DATA not added; it already exists")
     else:
         dminfo['NAME'] = 'modeldata'
         cdesc['comment'] = 'The model data column'
         t.addcols (maketabdesc(makecoldesc('MODEL_DATA', cdesc)), dminfo)
         if ack:
-            print 'added column MODEL_DATA'
+            six.print_("added column MODEL_DATA")
     if 'CORRECTED_DATA' in cnames:
-        print 'Column CORRECTED_DATA not added; it already exists'
+        six.print_("Column CORRECTED_DATA not added; it already exists")
     else:
         dminfo['NAME'] = 'correcteddata'
         cdesc['comment'] = 'The corrected data column'
         t.addcols (maketabdesc(makecoldesc('CORRECTED_DATA', cdesc)), dminfo)
         if ack:
-            print 'added column CORRECTED_DATA'
+            six.print_("'added column CORRECTED_DATA")
     if 'IMAGING_WEIGHT' in cnames:
-        print 'Column IMAGING_WEIGHT not added; it already exists'
+        six.print_("Column IMAGING_WEIGHT not added; it already exists")
     else:
         # Add IMAGING_WEIGHT which is 1-dim and has type float.
         # It needs a shape, otherwise the CASA imager complains.
@@ -95,7 +99,7 @@ def addImagingColumns(msname, ack=True):
         dminfo['NAME'] = 'imagingweight'
         t.addcols (maketabdesc(cd), dminfo)
         if ack:
-            print 'added column IMAGING_WEIGHT'
+            six.print_("added column IMAGING_WEIGHT")
     # Add or overwrite keyword CHANNEL_SELECTION.
     if 'CHANNEL_SELECTION' in t.colkeywordnames('MODEL_DATA'):
         t.removecolkeyword ('MODEL_DATA', 'CHANNEL_SELECTION')
@@ -106,7 +110,7 @@ def addImagingColumns(msname, ack=True):
     chans = [[0,nch] for nch in nchans]
     t.putcolkeyword ('MODEL_DATA', 'CHANNEL_SELECTION', np.int32(chans))
     if ack:
-        print 'defined keyword CHANNEL_SELECTION in column MODEL_DATA'
+        six.print_("defined keyword CHANNEL_SELECTION in column MODEL_DATA")
     # Flush the table to make sure it is written.
     t.flush()
 
@@ -362,7 +366,7 @@ def msregularize (msname, newname):
             ant1 = tsub.getcol('ANTENNA1')
             ant2 = tsub.getcol('ANTENNA2')
             t2 = taql('select from $t1 where !any(ANTENNA1 == $ant1 && ANTENNA2 == $ant2)')
-            print nmissing,t1.nrows(),tsub.nrows(),t2.nrows()
+            six.print_(nmissing, t1.nrows(),tsub.nrows(), t2.nrows())
             if t2.nrows() != nmissing:
                 raise ValueError("A time/band chunk behaves strangely")
             # If nothing added yet, create a new table.
@@ -392,8 +396,8 @@ def msregularize (msname, newname):
     else:
         tcombs = t.query(offset=0)
     tcombs.rename (newname)
-    print newname, 'has been created; it references the original MS'
+    six.print_(newname, 'has been created; it references the original MS')
     if nadded > 0:
-        print '  and', newname+'_adds', 'containing', nadded, 'new rows'
+        six.print_('  and', newname+'_adds', 'containing', nadded, 'new rows')
     else:
-        print '  no rows needed to be added'
+        six.print_('  no rows needed to be added')
