@@ -41,8 +41,8 @@ Several utility functions exist. Important ones are:
 
 
 # Make interface to class TableProxy available.
-from _tables import Table
-from tablehelper import _add_prefix, _remove_prefix, _do_remove_prefix
+from ._tables import Table
+from .tablehelper import _add_prefix, _remove_prefix, _do_remove_prefix
 from casacore import six
 
 # Execute a TaQL command on a table.
@@ -334,12 +334,13 @@ class table(Table):
 
     def _makerow (self):
         """Internal method to make its tablerow object."""
-        from tablerow import _tablerow;
+        from .tablerow import _tablerow;
         self._row = _tablerow (self, []);
     
     def __str__ (self):
-        """Return the table name."""
-        return _add_prefix (self.name());
+        """Return the table name and the basic statistics"""
+        return _add_prefix (self.name()) + "\n%d rows"%self.nrows() + "\n" + \
+          "%d columns: "%len(self.colnames())+" ".join(self.colnames());
     
     def __len__ (self):
         """Return the number of rows in the table."""
@@ -412,7 +413,7 @@ class table(Table):
           t.DATA[0:10]   # does the same in an easier way
 
         """
-        from tablecolumn import tablecolumn;
+        from .tablecolumn import tablecolumn;
         return tablecolumn (self, columnname);
 
     def row (self, columnnames=[], exclude=False):
@@ -422,7 +423,7 @@ class table(Table):
         more rows.
 
         """
-        from tablerow import tablerow;
+        from .tablerow import tablerow;
         return tablerow (self, columnnames, exclude);
 
     def iter (self, columnnames, order='', sort=True):
@@ -447,7 +448,7 @@ class table(Table):
             print ts.nrows()
 
         """
-        from tableiter import tableiter;
+        from .tableiter import tableiter;
         return tableiter (self, columnnames, order, sort);
 
     def index (self, columnnames, sort=True):
@@ -466,7 +467,7 @@ class table(Table):
           print tinx.rownumbers(0)       # print rownrs containing ANTENNA1=0
 
         """
-        from tableindex import tableindex;
+        from .tableindex import tableindex;
         return tableindex (self, columnnames, sort);
 
     def flush (self, recursive=False):
@@ -775,7 +776,7 @@ class table(Table):
     def isvarcol (self, columnname):
         """Tell if the column holds variable shaped arrays."""
         desc = self.getcoldesc(columnname);
-        return desc.has_key('ndim') and not desc.has_key('shape');
+        return 'ndim' in desc and not 'shape' in desc
 
     def coldatatype (self, columnname):
         """Get the data type of a column.
@@ -1126,12 +1127,12 @@ class table(Table):
         """
         tdesc = desc
         # Create a tabdesc if only a coldesc is given.
-        if desc.has_key('name'):
+        if 'name' in desc:
             import casacore.tables.tableutil
-            if len(desc)==2 and desc.has_key('desc'):
+            if len(desc)==2 and 'desc' in desc:
                 # Given as output from makecoldesc
                 tdesc = casacore.tables.tableutil.maketabdesc(desc);
-            elif desc.has_key('valueType'):
+            elif 'valueType' in desc:
             # Given as output of getcoldesc (with a name field added)
                 cd = casacore.tables.tableutil.makecoldesc (desc['name'], desc)
                 tdesc = casacore.tables.tableutil.maketabdesc(cd)
@@ -1436,7 +1437,7 @@ class table(Table):
         if columnname is None:
             return dminfo
         # Find the info for the given column
-        for fld in dminfo.itervalues():
+        for fld in dminfo.values():
             if columnname in fld["COLUMNS"]:
                 fldc = fld.copy();
                 del fldc['COLUMNS']     # remove COLUMNS field
